@@ -47,12 +47,20 @@ class Test_distilbert_model:
 
     def test_fit_adv(self):
         # self.model_distilbert_dev = build_distilbert_model_singleton(model_type="1st")
+
+        if DEBUG:
+            steps = 10
+            epochs = 1
+        else:
+            steps = TRAIN_LEN/BATCH_SIZE,
+            epochs = 8
+
         train_history = self.model_distilbert.fit(
             train_dataset,
-            steps_per_epoch=TRAIN_LEN/BATCH_SIZE,
+            steps_per_epoch=steps,
             validation_data=valid_dataset,
             callbacks=bert_cbs,
-            epochs=1
+            epochs=epochs
         )
     def test_result(self):
         may_debug()
